openedx-chem
============

A helper library for chemistry calculations,
used by the `edx-platform`_.

This code originally lived in the `edx-platform`_ repo,
but now exists here independently.


License
-------

The code in this repository is licensed under version 3 of the AGPL
unless otherwise noted. Please see the `LICENSE`_ file for details.


.. _edx-platform: https://github.com/openedx/edx-platform
.. _LICENSE: https://github.com/openedx/openedx-chem/blob/master/LICENSE
